@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from data_visualization_models.graph.network.network import Network
+from semantyk.data_visualization_models.graph.network.network import Network
 
 class GenealogicalTree(Network):
     pass
\ No newline at end of file
